A Singular Process.
In NComm (as with Ros) the main idea is to encapsulate singular processes into a singular Node.
The hope is that by encapsulating processes to specific structures it helps the readability and maintainability of robotics
projects.
Take, for example, a system consisting of a few sensors and a web server. To enhance the readability and maintainability of the project, it may be useful to separate each of the sensors into a specific Node that collects (and possibly processes) the various pieces of sensor data. Then, it may be necessary to combine the data at another node that is running the web server.
Each of the Modules below contains various examples used internally to test executor functionalities.
Modules
- Basic Node Example.
- Basic Client + Server Node Example.
- Basic Publisher + Server Node Example.
- Basic UDP Publisher + Client Example.
- Basic Update Client + Server Node Example.
Traits
- A Node should represent a comprehensive object/block of code that functions relatively independently from the other blocks of code.