Wrapper that manages the scheduling of Nodes.
An Executor should maintain references to a number of nodes and schedule their updates. The idea here is that each executor can pretty much be its own thread that manages its own set of processes.
Modules
- The Node Wrapper wraps a mutable reference to a node with information regarding its next update timestamp.
- Executes the update step of nodes on a singular thread.
- Executor that manages multiple single-threaded executors (Preferred).
Traits
- An executor should contain a large number of nodes which it will handle the calling of the update, start and other functions (an executor will take place on a singular thread)
- Trait to be implemented by all multi threaded executors to allow the addition of nodes into specific threads of the multi threaded executor.
- Trait to be implemented by all single threaded executors to allow the addition of nodes in the single threaded context.